bibliotheca Augustana

<<< Übersicht <<< vorige Seite
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 39. Aventiure
___________________________________________________
| ### Do> svocht der herre Dieterich selbe sin gewant ### im half daz er sich waffente meister Hildebrant ### do chlagete also sere der chrepftige man ### daz daz hus erdiezen von sinen chrepften began ### Do gewan er wider rehten heldes mvt ### in grimme wart gewafent do der helt gvt ### einen schilt vil vesten nam er an di hant ### si giengen dannen balde er vnde meister Hildebrant
###### 2323 | ### Do sprach von Tronege Hagene ich sihe dort her gan ### hern Dieterichen der wil vns bestan ### nach sinem starchem leide daz im ist hi geschehen ### man sol daz hivte chiesen wem man des besten mvge iehen
| ### Ian endunchet sich von Berne der herre Dieterich ### nie so starch des libes vnd ovch so griwelich ### vnd wil erz an vns rêchen daz im ist getan ### also redete Hagene ich tar in rehte wol bestan
###### 2325 | ### Dise rede horte Dieterich vnd ovh Hildebrant ### er chom da er di recken beide stende vant ### vzen vor dem huse geleinet an den sal [412a] ### sinen schilt den guten den satzet Dieterich ce tal
###### 2326 | ### In leidechlichen sorgen sprach do Dieterich ### wi habt ir so geworben Guenther chuenech rich ### wider mich ellenden waz het ich iv getan ### alles mines trostes des pin ich hie eine bestan
###### 2327 | ### Ivch enduhte niht der volle an der grozen not ### do ir vns Ruedegeren den helt sluget tot ### nv habet ir mir erbunnen aller miner man ### iane het ich iv helden soelher leide niht getan
###### 2328 | ### Gedenchet an ivch selben vnde an iwer leit ### tot der iwern vrivnde vnd ovch div arbeit ### ob ez iv guten recken beswæret iht den mut ### owe wi rehte vnsanpfte mir tot der Rvedgeres tvt
###### 2329 | ### Ez geschach ce dirre werlde nie leider manne mer ### ir gedahtet vebele an min vnd an iwer ser ### swaz ich frivnde hete di sint von iv erslagen ### iane chan ich nimmer mere di minen mage verchlagen
| ### Iane sin wir niht so schvldich sprach do Hagene ### ez giengen zv disem hvse iwer degene ### gewafent wol ce vlize mit einer schar so breit ### mich dunchet daz div mære iv niht rehte sin geseit
###### 2331 | ### Waz sol ich gelovben mære mir seitz Hildebrant ### do mine recken gerten von Amelvnge lant ### daz ir in Rvedgeren gæbet vz dem sal ### do but ir niwan spotten den chvenen helden her ce tal
###### 2332 | ### Do sprach der kvenech von Rine si iahen wolden tragen ### Rvedgeren hinnen den hiez ich in versagen ### Eceln ce leide vnd niht den dinen man ### vnz daz do Wolfhart dar vmbe shelten began
| ### Do sprach der helt von Berne ez mvst et also sin ### Gventher chvenech edele dvrch di zvht din ### ergetzze mich der leide di mir von dir sint geschehen ### vnd svene iz ritter chvene daz ich des chvenne dir geiehen
###### 2334 | ### Ergip dich mir ce gisel dv vnd ovch din man ### so wil ich behveten so ih aller beste chan ### daz dir cen Hivnen [412b] niemen niht en tvt
###### 2335 | ### Daz enwelle got von himele sprah do Hagene ### daz sich dir ergæben zwene degene ### di noch werliche gewaffent gegen dir stant ### vnd noch so ledechliche vor ir vianden gant
| ### Iren svlt iz niht versprechen so redete Dieterich ### Gventher vnde Hagene ir habt beide mich ### so ser beswæret daz herce vnd ovch den mvt ### welt ir mich ergezzen daz irz vil pilliche tvt
###### 2337 | ### Ich gibe iv mine triwe vnd sicherliche hant ### daz ich mir iv rite heim in iwer lant ### ich leit ivch nach den eren oder ich gelige tot ### vnd wil durch ivch vergezzen der minen groezlichen not
###### 2338 | ### Nvne muotet sin niht mere sprach aber Hagene ### von vns zimt daz mære niht wol ce sagene ### daz sich iv ergæben zwene also chvene man ### nv siht man bi iv niemen wan eine Hildebranden stan
| ### Do sprach meister Hildebrant got weiz her Hagene ### der iv den vride bivtet mit iv ce tragene ### ez chumt noch an di stunde daz ir moehtet nemen ### di svne mines herren moht ir iv lazen gezemen
###### 2340 | ### Ia næme ich di svne sprach aber Hagene ### ê ich so lasterliche vze einem gademe ### fluehe meister Hildebrant als ir hie habt getan ### ich wæne daz ir chundet baz gein vianden stan
###### 2341 | ### Des antwrte Hildebrant zwiv verwizet ir mir daz ### nv wer was der vf einem schilde vor dem Waskensteine saz ### do im von Spanye Walther so uil der frivnde slvch ### ovch habt ir noch ce zeigen an iv selben genuch
| ### Do sprach der herre Dieterich ez enzimt niht helde lip ### daz si svln shelten sam div alten wip ### ich verbivt iv Hildebrant daz ir niht sprechet mer ### mich ellenden recken twingent grozlichiv ser
###### 2343 | ### Lat horen sprach Dieterich recke Hagene ### waz ir beide <spræchet> [413a] snellen degene ### do ir mich gewafent zv ziv sahet gan ### ir iahet daz ir eine mit strite woldet mich bestan
###### 2344 | ### Iane lovgent iv des niemen sprach Hagen <der> degen ### ine wellez hie versvchen mit den starchen slegen ### ezen si daz mir cebreste daz Nibelunges swert ### mir ist zorn daz vnser beider ist ce gisel hie gegert
| ### Do Dieterich gehorte den grimmen Hagenen mvt ### den schilt vil balde zvchte der snelle degn gvt ### wi balde gein im Hagene von der stiege spranch ### Nivlvnges swert daz gvte vil lvt vf Dieteriche erchlanch
###### 2346 | ### Do wesse wol her Dieterich daz der chvene man ### vil grimmes mvtes wære schermen im began ### der herre von Berne vor <angeslichen> slegen ### wol erchand er Hagenen den vil zierlichen degen
###### 2347 | ### Ovch vorht er Balmungen ein wafen starch genvch ### vnder wilen Dietrich mit listen wider slvch ### vnz daz er Hagenen mit strite doch betwanch ### er slvch im eine wnden div was tief vnde lanch
| ### Do daht der herre Dietrich dv bist in noeten erwigen ### ich hans lvecel ere soltv tot vor mir geligen ### ich wilz sus versvchen ob ich ertwingen chan ### dich <mir> ce einem gisel daz wart mit sorgen getan
###### 2349 | ### Den schilt den liez er vallen sin sterche div was groz ### Hagenen von Tronege mit armen er besloz ### des wart do betwngen von im der chvene man ### Gventher der edele dar vmbe trvoren began
###### 2350 | ### Hagenen bant Dieterich vnd fvrt in da er vant ### di edeln kveneginne vnd gab ir bi der hant ### den chvenesten recken der ie swert getrvch ### nach ir vil starchem leide do wart si vroelich genvch
| ### Vor liebe neich dem degene daz Eceln wip ### immer si dir sælich din herce vnd ovch der [413b] lip ### dv hast mich wol ergezzet aller miner not ### daz sol ich immer dienen mich ensv^me danne der tot
###### 2352 | ### Do sprach der herre Dietrich ir svlt in lan genesen ### edliv chveneginne vnd mach daz noch gewesen ### wi wol er ivch ergezzet daz er iv hat getan ### ern sol des niht engelten daz ir in seht gebvnden stan
###### 2353 | ### Do hiez si Hagenen fveren an sin vngemach ### da er lach beslozen vnt da <niemen> sach ### Gventher der kvenech edele rveffen do began ### war chom der helt von Berne der hat mir leide getan
| ### Do gie im hin engegene der herre Dietrich ### daz Gventheres ellen daz was vil loblich ### done beit ovch er niht mere er lief her fver den sal ### von ir beider swerten huop sich ein groezlicher shal
###### 2355 | ### Swi vil der herre Dietrich lange was gelobt ### Gventher was so sere erzvernet vnd ertobt ### wand er nach starchem leide sin hercevient was ### man sagt ez noch ce wnder daz do her Dieterich genas
###### 2356 | ### Ir ellen vnd ir sterche beider waren groz ### palas vnd tvrne von den slegen doz ### do si mit swerten hiwen vf die helme gvt ### ez het der kvenech Gventher einen herlichen mvt
| ### Sit twang in der von Berne sam Hagenen ê geschach ### daz plvot man dvrch di ringe dem helde vliezen sach ### von einem sharpfen swerte daz trvch Dietrich ### do het gewert her Gventher nach mvede lobeliche sich
###### 2358 | ### Der herre wart gebvnden von Dietriches hant ### swi chvenege nine solden liden solhiv bant ### er daht ob er si lieze den kvenech vnde sinen man ### alle di si fvenden di mvesen tot von in bestan
###### 2359 | ### Dieterich von Berne der nam in bi der hant ### do fvrt er in gebunden da er Criemhilde vant ### do was mit sinem leide ir sorgen [414a] vil erwant ### si sprach <willechom> Gventher vzer Bvrgonden lant
| ### Er sprach ich sol iv nigen vil liebiv swester min ### ob iwer grvezen moehte genædechlicher sin ### ich weiz ivch kveneginne so zornech gemvt ### daz ir mich vnde Hagenen vil swache grvezen getvt
###### 2361 | ### Do sprach der helt von Berne vil edeles chveneges wip ### ezen wart gisel mere so guter ritter lip ### als ich vrowe here iv an in gegebn han ### nv svlt ir di ellenden min vil wol geniezen lan
###### 2362 | ### Si iach si tæt iz gerne do gi her Dieterich ### mit weinenden ovgen von den helden lobelich ### sit rach sich grimmechlichen daz Eceln wip ### den vz erwelten degenen nam si beiden den lip
| ### Si lie si ligen besvnder dvrch ir vngemach ### daz ir sit deweder den andern ni gesach ### vnz si ir brvder hovbet hin fver Hagenen trvch ### der Criemhilde rache wart an in beiden genvch
###### 2364 | ### Do gie div chvneginne da si Hagenen sach ### wi rehte fientliche si zv dem helde sprach ### welt ir mir geben wider daz ir mir habt genomen ### so mvget ir wol lebende heim cen Bvrgonden chomen
###### 2365 | ### Do sprach der grimme Hagene div rede ist gar verlorn ### vil edliv chveneginne ia han ich des gesworn ### daz ich den hort iht zeige di wile daz si leben ### deheiner miner herren so sol ich in niemene geben
| ### Ich bringez an ein ende so sprah daz edel wip ### do hiez si ir bruder nemen sinen vil shonen <lip> ### slvch im ab daz hovbet bi dem hare si ez trvch ### fver den helt von Tronege do wart im leide genvch
###### 2367 | ### Also der vngemvote sines herren hovbet sah ### wider Criemhilde do der recke sprach ### dv hast iz nach dinem willen vil gar zeinem ende braht ### vnd ist ovch iv ergangen als ich mir het gedaht [414b]
###### 2368 | ### Nv ist von Bvrgonden der edel kvenech tot ### Giselher der ivnge vnde ovch her Gernot ### den shaz den weiz nv niemen wan got ane min ### der sol dich valendinne immer verborgen sin
| ### Si sprach so habt ir vebele geltes mich gewert ### so wil ich doch behalten daz Sifrides swert ### daz truch min holder vriedel do ich in ivngest sach ### an dem mir herceleide von iwern shvlden geschach
###### 2370 | ### Si zoh iz von der scheiden daz chvnd er niht erwern ### do daht si den recken des libes wol behern ### si hvb im vf daz hovbt mit dem swerte siz ab slvch ### daz sach der kvenech Ecel do was im leide genvch
###### 2371 | ### Waffen sprach der fverste wi ist nv tot gelegen ### von eines wibes handen der aller beste degen ### der ie chom ce stvrme oder ie schilt getrvch ### swi vient ich im wære ez ist mir leide genvch
| ### Do sprach der alte Hildebrant ia genivzet si des niht ### daz si in slahen torste swaz mir da von <geschit> ### swi er mich selbe bræhte in angestliche not ### idoh so wil ich recken des chvenen Tronegæres tot
###### 2373 | ### Hildebrant mit zorne zv Criemhilde spranch ### er slvch der chveneginne einen swæren <swert> swanch ### ia tet ir div sorge von Hildebrande we ### waz mohte si gehelffen daz si groezlichen shre
###### 2374 | ### Do was gelenget aller da der veigen lip ### ze stvcken was gehowen do daz edele wip ### Dieterich vnd Ecel weinen do began ### si chlagten innechliche beide mage vnd man
| ### Div vil michel ere was gelegen tot ### di livte heten alle iamer vnde not ### mit leide was verendet des kveneges hohgezit ### als ie div liebe leide zaller ivngeste git
###### 2376 | ### Ine chan iv niht bescheiden waz [415a] sider da geschach ### wan ritter vnd vrowen weinen man da sach ### dar zv di edeln knehte ir lieben frivnde tot ### da hat daz mære ein ende diz ist der Nibelvnge <not>

<<< Übersicht <<< vorige Seite